<template>
  <!-- 勤务岗位信息添加 -->
  <div>
    <el-dialog
      :title="title + '勤务岗位信息'"
      :visible.sync="showFormDia"
      width="76%"
      :before-close="handleClose"
      top="8vh"
    >
      <div>
        <el-form ref="formInfo" :rules="rules" :model="params" label-width="100px">
          <el-collapse v-model="activeCollapseNames" class="form-collapse">
            <el-collapse-item name="1">
              <template slot="title">
                <span class="collapse-title">
                  <i class="collapse-title-icon el-icon-info" />
                  勤务岗位信息
                </span>
              </template>

              <el-row>
                <el-col :span="8">
                  <el-form-item label="编号" prop="code">
                    <el-input v-model="params.code" clearable :maxlength="255" placeholder="请输入编号" />
                  </el-form-item>
                </el-col>
                <el-col :span="8">
                  <el-form-item label="名称" prop="name">
                    <el-input v-model="params.name" clearable :maxlength="100" placeholder="请输入名称"
                              show-word-limit />
                  </el-form-item>
                </el-col>
                <el-col :span="8">
                  <el-form-item label="负责区域" prop="areaList">
                    <el-cascader
                      v-model="params.areaList"
                      :options="equipmentList"
                      :show-all-levels="false"
                      :props="{ multiple: true,value:'code',label:'name',emitPath:false }"
                      clearable
                      placeholder="请选择负责区域"
                      style="width:100%"
                    ></el-cascader>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="24">
                  <el-form-item label="职责描述">
                    <el-input
                      v-model="params.description"
                      :rows="3"
                      :maxlength="500"
                      show-word-limit
                      type="textarea"
                      style="width:100%;"
                    />
                  </el-form-item>
                </el-col>
              </el-row>
              <!-- <el-row>
                <el-col :span="24">
                  <el-form-item label="负责区域">
                    <el-input
                      v-model="params.area"
                      :rows="3"
                      :maxlength="500"
                      show-word-limit
                      type="textarea"
                      style="width:100%;"
                    />
                  </el-form-item>
                </el-col>
              </el-row> -->
              <el-row>
                <el-col :span="24">
                  <el-form-item label="备注">
                    <el-input
                      v-model="params.memo"
                      :rows="3"
                      :maxlength="500"
                      show-word-limit
                      type="textarea"
                      style="width:100%;"
                    />
                  </el-form-item>
                </el-col>
              </el-row>
            </el-collapse-item>
          </el-collapse>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" :loading="loading" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import CmgtDutyJobApi from '@/views/Manage/duty/api/CmgtDutyJobApi'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
import {mapState} from 'vuex'

export default {
  name: 'CmgtDutyJobFormDialog',
  components: {},
  props: {
    equipmentList: {
      type: Array,
      default: []
    }
  },
  data() {
    return {
      title: '新增',
      CommonApi,
      showFormDia: false,
      loading: false,
      activeCollapseNames: ['1'],
      activeTabChildName: '0',

      params: {
        code: null,
        name: null,
        description: null,
        // area: null,
        memo: null,
        areaList: []
      },
      rules: {
        code: [
          {required: true, message: '编号不能为空', trigger: 'blur'}
        ],
        name: [
          {required: true, message: '名称不能为空', trigger: 'blur'}
        ],
        areaList: [
          {required: true, message: '负责区域不能为空', trigger: 'blur'}
        ]
      }
    }
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  created() {
  },
  methods: {
    add() {
      this.title = '新增'
      this.resetForm()
      this.showFormDia = true
    },
    resetForm() {
      this.params = {
        code: null,
        name: null,
        description: null,
        // area: null,
        memo: null,
        areaList: []
      }
    },
    handleClose() {
      this.resetForm()
      this.showFormDia = false
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          this.params.areaList = this.params.areaList.map(item => {
            return {
              areaCode: item
            }
          })
          let method
          if (!this.params.id) {
            // 新增
            method = CmgtDutyJobApi.addCmgtDutyJob
          } else {
            // 修改
            method = CmgtDutyJobApi.editCmgtDutyJob
          }
          this.loading = true
          method(this.params, res => {
            this.loading = false
            if (res.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              // this.$emit('loadData')
              this.$parent.loadData()
              this.handleClose()
            } else {
              this.$message.warning(res.message)
            }
          })
        }
      })
    },
    Update(row) {
      this.title = '修改'
      this.showFormDia = true
      CmgtDutyJobApi.getCmgtDutyJobByID(row.id, res => {
        console.log(res)
        res.areaList = res.areaList.map(item => {
          return item.areaCode
        })
        this.params = res
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}
</style>
